@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,14 +24,13 @@
 #include <QObject>
 #include <QProcess>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposer;
 class KPIMTEXTEDIT_EXPORT RichTextExternalComposer : public QObject
 {
     Q_OBJECT
 public:
-    explicit RichTextExternalComposer(RichTextComposer *composer, QObject *parent = Q_NULLPTR);
+    explicit RichTextExternalComposer(RichTextComposer *composer, QObject *parent = nullptr);
     ~RichTextExternalComposer();
 
     bool useExternalEditor() const;
