@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -76,6 +76,7 @@ public:
 
         mainLayout->addWidget(buttonBox);
     }
+
     QCheckBox *useBackgroundColor;
 
     KColorButton *backgroundColor;
@@ -84,7 +85,8 @@ public:
 };
 
 TableCellFormatDialog::TableCellFormatDialog(QWidget *parent)
-    : QDialog(parent), d(new TableCellFormatDialogPrivate(this))
+    : QDialog(parent)
+    , d(new TableCellFormatDialogPrivate(this))
 {
 }
 
@@ -108,7 +110,7 @@ QTextCharFormat::VerticalAlignment TableCellFormatDialog::verticalAlignment() co
 {
     return
         (QTextCharFormat::VerticalAlignment)d->verticalAlignment->itemData(
-            d->verticalAlignment->currentIndex()).toInt();
+        d->verticalAlignment->currentIndex()).toInt();
 }
 
 void TableCellFormatDialog::setVerticalAlignment(QTextCharFormat::VerticalAlignment vertical)
