@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,14 +26,12 @@
 class QAction;
 class QLineEdit;
 class QPushButton;
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class TextFindWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TextFindWidget(QWidget *parent = Q_NULLPTR);
+    explicit TextFindWidget(QWidget *parent = nullptr);
     ~TextFindWidget();
 
     QTextDocument::FindFlags searchOptions() const;
@@ -67,7 +65,7 @@ class TextReplaceWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TextReplaceWidget(QWidget *parent = Q_NULLPTR);
+    explicit TextReplaceWidget(QWidget *parent = nullptr);
     ~TextReplaceWidget();
 
     QLineEdit *replace() const;
